@@ -56,11 +56,11 @@ class MetricConfig(dict):
 
     name: str
     language: str = "en"
-    cls: str = ''
+    cls_name: str = ''
 
     def __post_init__(self):
         # Save the class name
-        self.cls = type(self).__name__
+        self.cls_name = type(self).__name__
 
     def to_metric(self):
         raise NotImplementedError
